@@ -303,7 +303,7 @@ parseEclipse <- function(x, planInfo=FALSE, courseAsID=FALSE, ...) {
                       grepl(patVolD, vars2)))
         if(length(vars2) != hits) {
             stop(c("Could not identify all DVH columns"),
-        		 paste(vars2, collapse=", "))
+        		 toString(vars2))
         }
 
         ## replace column headers
