@@ -1,7 +1,8 @@
 #####---------------------------------------------------------------------------
 ## returns a list (1 component per DVH file) of lists (1 component = 1 list per structure)
 readDVH <- function(x, type=c("Eclipse", "Cadplan", "Masterplan", "Pinnacle",
-                              "Monaco", "HiArt", "RayStation", "ProSoma", "PRIMO"),
+                              "Monaco", "HiArt", "RayStation", "ProSoma",
+                              "PRIMO", "Mirada"),
                     planInfo=FALSE, courseAsID=FALSE, add, ...) {
     type <- match.arg(type)
 
@@ -20,7 +21,22 @@ readDVH <- function(x, type=c("Eclipse", "Cadplan", "Masterplan", "Pinnacle",
                        HiArt=parseHiArt,
                        RayStation=parseRayStation,
                        ProSoma=parseProSoma,
-                       PRIMO=parsePRIMO)
+                       PRIMO=parsePRIMO,
+                       Mirada=parseMirada)
+
+    ## if both volume_from_dvh and hiart / mirada / raystation are
+    ## provided as additional arguments, need to put them in the same
+    ## list here so nothing gets lost in call to Map()
+    # dots <- list(...)
+    # type_special <- c("hiart", "mirada", "raystation")
+    # if(hasName(dots, "volume_from_dvh") && any(hasName(dots, type_special))) {
+    #     idx <- which(names(dots) %in% type_special)
+    #     stopifnot(length(idx) == 1L)
+    #     type_special_have <- type_special[type_special == names(dots)[idx]]
+    #     dots[[idx]][["volume_from_dvh"]] <- dots[["volume_from_dvh"]]
+    #     dots[["volume_from_dvh"]] <- NULL
+    #     dots <- setNames(list(dots), type_special_have)
+    # }
 
     dvhLL <- if(length(dvhRawL) >= 1L) {
         res <- Map(parseFun, dvhRawL, planInfo=planInfo, courseAsID=courseAsID, ...)
@@ -30,9 +46,9 @@ readDVH <- function(x, type=c("Eclipse", "Cadplan", "Masterplan", "Pinnacle",
         NULL
     }
 
-    ## for HiArt, ProSoma and PRIMO files, no patient ID is given
+    ## for HiArt, ProSoma, PRIMO, and Mirada files, no patient ID is given
     ## -> copy the random ID generated in parseDVH() to all DVHs
-    if(type %in% c("HiArt", "ProSoma", "PRIMO")) {
+    if(type %in% c("HiArt", "ProSoma", "PRIMO", "Mirada")) {
         setID <- function(dvhL, id) {
             dvhLOut <- lapply(dvhL, function(y) {
                 y$patID <- id
@@ -125,7 +141,7 @@ mergeDVH <- function(...)  {
 #####---------------------------------------------------------------------------
 ## check DVH matrix for having increasing dose
 isIncreasing <- function(x)  {
-    dose <- if(!any(is.na(x[ , "dose"]))) {
+    dose <- if(!anyNA(x[ , "dose"])) {
         x[ , "dose"]
     } else {
         x[ , "doseRel"]
@@ -138,7 +154,7 @@ isIncreasing <- function(x)  {
 ## check DVH matrix if differential or cumulative
 dvhType <- function(x)  {
     ## check if volume is already sorted -> cumulative DVH
-    volume <- if(!any(is.na(x[ , "volumeRel"]))) {
+    volume <- if(!anyNA(x[ , "volumeRel"])) {
         x[ , "volumeRel"]
     } else {
         x[ , "volume"]
