@@ -41,7 +41,8 @@ function(x, cumul=TRUE, interp=FALSE, rangeD=NULL) {
 showDVH <-
 function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
          guessX=TRUE, guessY=TRUE, thresh=1, addMSD=FALSE,
-         show=TRUE, visible=FALSE, fixed=TRUE) {
+         show=TRUE, visible=FALSE, fixed=TRUE,
+         fun=list(location=mean, uncertainty=sd)) {
     UseMethod("showDVH")
 }
 
@@ -49,7 +50,8 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
 showDVH.DVHs <-
 function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
          guessX=TRUE, guessY=TRUE, thresh=1, addMSD=FALSE,
-         show=TRUE, visible=FALSE, fixed=TRUE) {
+         show=TRUE, visible=FALSE, fixed=TRUE,
+         fun=list(location=mean, uncertainty=sd)) {
     x <- if(byPat) {
         setNames(list(x), x$structure)
     } else {
@@ -61,7 +63,8 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
 
     showDVH.DVHLst(x, cumul=cumul, byPat=byPat, patID=patID, structure=structure,
                    rel=rel, guessX=guessX, guessY=guessY, thresh=thresh,
-                   addMSD=addMSD, show=show, visible=visible)
+                   addMSD=addMSD, show=show, visible=visible, fixed=fixed,
+                   fun=fun)
 }
 
 ## plots 1 list of DVH objects
@@ -70,7 +73,8 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
 showDVH.DVHLst <-
 function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
          guessX=TRUE, guessY=TRUE, thresh=1, addMSD=FALSE,
-         show=TRUE, visible=FALSE, fixed=TRUE) {
+         show=TRUE, visible=FALSE, fixed=TRUE,
+         fun=list(location=mean, uncertainty=sd)) {
 
     ## make sure DVH list is organized as required for byPat
     if(is.null(attributes(x)$byPat) || attributes(x)$byPat != byPat) {
@@ -78,6 +82,10 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
                "either could not be determined or is different from byPat"))
     }
 
+    if(addMSD) {
+        stopifnot(length(fun) == 2L)
+    }
+
     guessX <- as.numeric(guessX)
     guessY <- as.numeric(guessY)
 
@@ -214,13 +222,15 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
 
     ## check if point-wise volume mean and sd should be plotted
     if(addMSD) {
+        fun_loc <- fun[["location"]]
+        fun_sd  <- fun[["uncertainty"]]
         ## generate point-wise mean/sd for dose -> aggregate over dose
         if(byPat) {
-            dfM  <- aggregate(volPlot ~ patID + dose,     data=dvhDF, FUN=mean, na.rm=TRUE)
-            dfSD <- aggregate(volPlot ~ patID + dose,     data=dvhDF, FUN=sd,   na.rm=TRUE)
+            dfM  <- aggregate(volPlot ~ patID + dose,     data=dvhDF, FUN=fun_loc, na.rm=TRUE)
+            dfSD <- aggregate(volPlot ~ patID + dose,     data=dvhDF, FUN=fun_sd,  na.rm=TRUE)
         } else {
-            dfM  <- aggregate(volPlot ~ structure + dose, data=dvhDF, FUN=mean, na.rm=TRUE)
-            dfSD <- aggregate(volPlot ~ structure + dose, data=dvhDF, FUN=sd,   na.rm=TRUE)
+            dfM  <- aggregate(volPlot ~ structure + dose, data=dvhDF, FUN=fun_loc, na.rm=TRUE)
+            dfSD <- aggregate(volPlot ~ structure + dose, data=dvhDF, FUN=fun_sd,  na.rm=TRUE)
         }
 
         ## rename columns in aggregated data frames
@@ -246,20 +256,21 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
     doseUnit <- if(isDoseRel) {
         "%"
     } else {
-        x[[1]]$doseUnit
+        unname(c(MGY="mGy", CGY="cGy", GY="Gy")[x[[1]]$doseUnit])
     }
 
-    volUnit <- if(rel) {
+    volStr <- if(rel) {
         if(cumul) {
-            "%"
+            "Volume (%)"
         } else {
-            paste0("%/", doseUnit)
+            paste0("Volume (%/", doseUnit, ")")
         }
     } else {
+        volU <- c(CC="cm^{3}")[x[[1]]$volumeUnit]
         if(cumul) {
-            x[[1]]$volumeUnit
+            str2expression(paste0("Volume~(", volU, ")"))
         } else {
-            paste0(x[[1]]$volumeUnit, "/", doseUnit)
+            str2expression(paste0("Volume~(", volU, "/", doseUnit, ")"))
         }
     }
 
@@ -323,8 +334,8 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
         # expand_limits(y=0) +                      # make sure 0 is included
         scale_y_continuous(expand=c(0, 0.6)) +
         guides(color=guide_legend(ncol=nLegendCols)) +
-        xlab(paste0("Dose [",   doseUnit, "]")) +
-        ylab(paste0("Volume [", volUnit,  "]"))
+        xlab(paste0("Dose (",   doseUnit, ")")) +
+        ylab(volStr)
 
     if(show) {
         print(diag)
@@ -344,7 +355,8 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
 showDVH.DVHLstLst <-
 function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
          guessX=TRUE, guessY=TRUE, thresh=1, addMSD=FALSE,
-         show=TRUE, visible=FALSE, fixed=TRUE) {
+         show=TRUE, visible=FALSE, fixed=TRUE,
+         fun=list(location=mean, uncertainty=sd)) {
 
     ## re-organize x into by-patient or by-structure form if necessary
     isByPat <- attributes(x)$byPat
@@ -385,7 +397,8 @@ function(x, cumul=TRUE, byPat=TRUE, patID=NULL, structure=NULL, rel=TRUE,
     diagL <- Map(showDVH, x, cumul=cumul, byPat=byPat, rel=rel,
                  patID=list(patID), structure=list(structure),
                  guessX=guessX, guessY=guessY, thresh=thresh,
-                 addMSD=addMSD, show=show, visible=visible, fixed=fixed)
+                 addMSD=addMSD, show=show, visible=visible,
+                 fixed=fixed, fun=list(fun))
 
     if(visible) {
         diagL
